# COUNTRIES
# PL, DE, AT, CZ, IT, ES

# Models for POLAND

# ADL model -- Table 3
SpecLM <- dP ~ L(dPNL, 0) + L(Pr,1)+ L(dBRENT, 0) + L(BRENTr, 1)+L(dAPI, 0) + L(APIr, 1)+ L(Idm/100, 1) + L(Th/100, 1)

tmp          <- yts[,c("dPDE","PDEr","IDEd","TDEh","dPNL","dBRENT","BRENTr","dAPI","APIr")]
names(tmp)  <- c("dP","Pr","Idm","Th","dPNL","dBRENT","BRENTr","dAPI","APIr")
MDE<-dynlm(SpecLM,data = tmp)
summary(MDE) 
Acf(as.numeric(MDE$residuals))

# GARCH model -- Table 4
dt1 <- dt %>%
  mutate(
    PDEr1      = dplyr::lag(PDEr,1),
    PPLr1      = dplyr::lag(PPLr,1),
    PATr1      = dplyr::lag(PATr,1),
    PCZr1      = dplyr::lag(PCZr,1),
    PITr1      = dplyr::lag(PITr,1),
    PESr1      = dplyr::lag(PESr,1),
    BRENTr1      = dplyr::lag(BRENTr,1),
    APIr1      = dplyr::lag(APIr,1),
    IDEd1      = dplyr::lag(IDEd,1)/100,
    IPLd1      = dplyr::lag(IPLd,1)/100,
    IATd1      = dplyr::lag(IATd,1)/100,
    ICZd1      = dplyr::lag(ICZd,1)/100,
    IITd1      = dplyr::lag(IITd,1)/100,
    IESd1      = dplyr::lag(IESd,1)/100,
    TDEh1      = dplyr::lag(TDEh,1)/100,
    TPLh1      = dplyr::lag(TPLh,1)/100,
    TATh1      = dplyr::lag(TATh,1)/100,
    TCZh1      = dplyr::lag(TCZh,1)/100,
    TITh1      = dplyr::lag(TITh,1)/100,
    TESh1      = dplyr::lag(TESh,1)/100
  )
dt1 <- na.omit(dt1)
y1 <- zoo(dt1[,-1],order.by=dt1$Dates)

# Model PL:
xreg = as.matrix(dt1[,c("dPNL","PPLr1","dBRENT","BRENTr1","dAPI","APIr1","IPLd1","TPLh1")])
spec = ugarchspec(variance.model=list(model="sGARCH", garchOrder=c(1,1)), 
                  mean.model=list(armaOrder=c(0,1), include.mean=TRUE,external.regressors = xreg),  
                  distribution.model="sstd")
GPL = ugarchfit(data=y1$dPPL, spec=spec, solver="hybrid")
GPL

# Simple GARCH model -- Table 5
# Model PL:
xreg = as.matrix(dt1[,c("dPNL","PPLr1")])
spec = ugarchspec(variance.model=list(model="sGARCH", garchOrder=c(1,1)), 
                  mean.model=list(armaOrder=c(0,1), include.mean=TRUE,external.regressors = xreg),  
                  distribution.model="sstd")
GPLsmall = ugarchfit(data=y1$dPPL, spec=spec, solver="hybrid")
GPLsmall
